package com.zyc.system.service;

import java.util.List;
import com.zyc.system.domain.MassiveDatabaseServices;

/**
 * 海量数据库服务Service接口
 * 
 * @author zyc
 * @date 2024-12-26
 */
public interface IMassiveDatabaseServicesService 
{
    /**
     * 查询海量数据库服务
     * 
     * @param id 海量数据库服务主键
     * @return 海量数据库服务
     */
    public MassiveDatabaseServices selectMassiveDatabaseServicesById(Integer id);

    /**
     * 查询海量数据库服务列表
     * 
     * @param massiveDatabaseServices 海量数据库服务
     * @return 海量数据库服务集合
     */
    public List<MassiveDatabaseServices> selectMassiveDatabaseServicesList(MassiveDatabaseServices massiveDatabaseServices);

    /**
     * 新增海量数据库服务
     * 
     * @param massiveDatabaseServices 海量数据库服务
     * @return 结果
     */
    public int insertMassiveDatabaseServices(MassiveDatabaseServices massiveDatabaseServices);

    /**
     * 修改海量数据库服务
     * 
     * @param massiveDatabaseServices 海量数据库服务
     * @return 结果
     */
    public int updateMassiveDatabaseServices(MassiveDatabaseServices massiveDatabaseServices);

    /**
     * 批量删除海量数据库服务
     * 
     * @param ids 需要删除的海量数据库服务主键集合
     * @return 结果
     */
    public int deleteMassiveDatabaseServicesByIds(Integer[] ids);

    /**
     * 删除海量数据库服务信息
     * 
     * @param id 海量数据库服务主键
     * @return 结果
     */
    public int deleteMassiveDatabaseServicesById(Integer id);
}
