package com.zyc.web.controller.api;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.zyc.common.annotation.Log;
import com.zyc.common.core.controller.BaseController;
import com.zyc.common.core.domain.AjaxResult;
import com.zyc.common.enums.BusinessType;
import com.zyc.system.domain.MassiveDatabaseServices;
import com.zyc.system.service.IMassiveDatabaseServicesService;
import com.zyc.common.utils.poi.ExcelUtil;
import com.zyc.common.core.page.TableDataInfo;

/**
 * 海量数据库服务Controller
 * 
 * @author zyc
 * @date 2024-12-26
 */
@RestController
@RequestMapping("/system/MassiveDatabaseServicesController")
public class MassiveDatabaseServicesController extends BaseController
{
    @Autowired
    private IMassiveDatabaseServicesService massiveDatabaseServicesService;

    /**
     * 查询海量数据库服务列表
     */
    @PreAuthorize("@ss.hasPermi('system:services:list')")
    @GetMapping("/list")
    public TableDataInfo list(MassiveDatabaseServices massiveDatabaseServices)
    {
        startPage();
        List<MassiveDatabaseServices> list = massiveDatabaseServicesService.selectMassiveDatabaseServicesList(massiveDatabaseServices);
        return getDataTable(list);
    }

    /**
     * 导出海量数据库服务列表
     */
    @PreAuthorize("@ss.hasPermi('system:services:export')")
    @Log(title = "海量数据库服务", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, MassiveDatabaseServices massiveDatabaseServices)
    {
        List<MassiveDatabaseServices> list = massiveDatabaseServicesService.selectMassiveDatabaseServicesList(massiveDatabaseServices);
        ExcelUtil<MassiveDatabaseServices> util = new ExcelUtil<MassiveDatabaseServices>(MassiveDatabaseServices.class);
        util.exportExcel(response, list, "海量数据库服务数据");
    }

    /**
     * 获取海量数据库服务详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:services:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Integer id)
    {
        return success(massiveDatabaseServicesService.selectMassiveDatabaseServicesById(id));
    }

    /**
     * 新增海量数据库服务
     */
    @PreAuthorize("@ss.hasPermi('system:services:add')")
    @Log(title = "海量数据库服务", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody MassiveDatabaseServices massiveDatabaseServices)
    {
        return toAjax(massiveDatabaseServicesService.insertMassiveDatabaseServices(massiveDatabaseServices));
    }

    /**
     * 修改海量数据库服务
     */
    @PreAuthorize("@ss.hasPermi('system:services:edit')")
    @Log(title = "海量数据库服务", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody MassiveDatabaseServices massiveDatabaseServices)
    {
        return toAjax(massiveDatabaseServicesService.updateMassiveDatabaseServices(massiveDatabaseServices));
    }

    /**
     * 删除海量数据库服务
     */
    @PreAuthorize("@ss.hasPermi('system:services:remove')")
    @Log(title = "海量数据库服务", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Integer[] ids)
    {
        return toAjax(massiveDatabaseServicesService.deleteMassiveDatabaseServicesByIds(ids));
    }
}
